import axios from 'axios';
import AdminLayout from './layout';
import { API_URL, currencyFormatter } from '@pos/base';
import { useEffect, useState } from 'react';
import { Card, Col, DatePicker, notification, Row, Table, Typography } from 'antd';
import dayjs from 'dayjs';
import lodash, { filter } from 'lodash';
import { v4 } from 'uuid';

export default function Admin() {
  const [dataItem, setDataItem] = useState<any[]>([]);
  const [dataItemMaster, setDataItemMaster] = useState<any[]>([]);

  const [dataItemKeys, setDataItemKeys] = useState<any[]>([]);
  const [dataItemMasterKeys, setDataItemMasterKeys] = useState<any[]>([]);

  const [loadingDataItem, setLoadingDataItem] = useState<boolean>(false);
  const [loadingDataItemMaster, setLoadingDataItemMaster] = useState<boolean>(false);
  const [filterDate, setFilerDate] = useState(dayjs());

  async function getDataItem(params: any) {
    setLoadingDataItem(true);
    await axios
      .get(API_URL.REPORT_SUMMARY_INCOME_ITEM, { params: params })
      .then((resp) => {
        const data = resp.data.data;

        const groupedData = lodash(data)
          .groupBy('item_owner') // Group by item_owner
          .map((items, owner) => ({
            // Map over each group to sum values and keep children
            title: owner,
            tr_item__qty: lodash.sumBy(items, (item) => Number(item.tr_item__qty)), // Convert to number
            tr_item__total_net_price: lodash.sumBy(items, (item) => Number(item.tr_item__total_net_price)), // Convert to number
            children: items.map((item) => {
              return { ...item, title: item.tr_item__item_name };
            }), // Include the original data as children
          }))
          .value()
          .map((item) => {
            return {
              key: v4(),
              ...item,
            };
          });

        setDataItemKeys(groupedData.map((item) => item.key));
        setDataItem(groupedData);
      })
      .catch((err) => {
        notification.error({ message: err?.message });
      })
      .finally(() => {
        setLoadingDataItem(false);
      });
  }

  async function getDataItemMaster(params: any) {
    setLoadingDataItemMaster(true);
    await axios
      .get(API_URL.REPORT_SUMMARY_INCOME_ITEM_MASTER, { params: params })
      .then((resp) => {
        const data = resp.data.data;
        const groupedData = lodash(data)
          .groupBy('item_owner') // Group by item_owner
          .map((items, owner) => ({
            // Map over each group to sum values and keep children
            title: owner,
            tr_item__qty: lodash.sumBy(items, (item) => Number(item.tr_item__qty)), // Convert to number
            tr_item_bundling__total_net_price: lodash.sumBy(items, (item) =>
              Number(item.tr_item_bundling__total_net_price),
            ), // Convert to number
            children: items.map((item) => {
              let title = '';
              if (item.tr_item_bundling__item_name) {
                title = `${item.tr_item_bundling__item_name} / ${item.tr_item__item_name}`;
              } else {
                title = item.tr_item__item_name;
              }
              return { ...item, title: title };
            }), // Include the original data as children
          }))
          .value()
          .map((item) => {
            return {
              key: v4(),
              ...item,
            };
          });

        setDataItemMasterKeys(groupedData.map((item) => item.key));
        setDataItemMaster(groupedData);
      })
      .catch((err) => {
        notification.error({ message: err?.message });
      })
      .finally(() => {
        setLoadingDataItemMaster(false);
      });
  }

  function handleGetDate(date: any) {
    getDataItem({ date });
    getDataItemMaster({ date });
  }

  useEffect(() => {
    if (filterDate) {
      handleGetDate(filterDate.format('DD-MM-YYYY'));
    }
  }, [filterDate]);

  return (
    <AdminLayout>
      <Row>
        <Col xl={8} lg={8} md={12} span={24}>
          <DatePicker
            size="large"
            popupStyle={{ fontSize: 18 }}
            allowClear={false}
            value={filterDate}
            style={{ width: '100%' }}
            format={'DD-MM-YYYY'}
            onChange={setFilerDate}
          />
        </Col>
      </Row>
      <div style={{ marginBottom: 20 }}></div>

      <Card
        title={
          <div style={{ paddingTop: 10, paddingBottom: 10 }}>
            <div style={{ fontSize: 16, fontWeight: 600 }}>Pendapatan Per Item</div>
            <div
              style={{ fontWeight: 400, fontSize: 12, color: 'grey' }}
            >{`Laporan pendapatan item per tanggal ${filterDate.format('DD-MM-YYYY')}`}</div>
          </div>
        }
      >
        <Table
          bordered
          size="small"
          dataSource={dataItem}
          pagination={false}
          loading={loadingDataItem}
          scroll={{ x: 'max-width', y: 350 }}
          rowKey={(child) => child.key} // Make sure each child row has a unique key
          expandable={{ expandedRowKeys: dataItemKeys, showExpandColumn: false }}
          rowClassName={(row) => (row.key ? 'row-group' : '')}
          rowHoverable={false}
          columns={[
            { key: 'title', dataIndex: 'title', title: 'TITLE', width: 170 },
            { key: 'tr_item__qty', dataIndex: 'tr_item__qty', title: 'PAX', width: 70 },
            {
              key: 'tr_item__total_net_price',
              dataIndex: 'tr_item__total_net_price',
              title: 'REVENUE',
              width: 120,
              render: (value) => currencyFormatter({ value }),
            },
          ]}
        />
      </Card>
      <div style={{ marginBottom: 20 }}></div>
      <Card
        title={
          <div style={{ paddingTop: 10, paddingBottom: 10 }}>
            <div style={{ fontSize: 16, fontWeight: 600 }}>Pendapatan Per Item Master</div>
            <div
              style={{ fontWeight: 400, fontSize: 12, color: 'grey' }}
            >{`Laporan pendapatan item master per tanggal ${filterDate.format('DD-MM-YYYY')}`}</div>
          </div>
        }
      >
        <Table
          bordered
          size="small"
          dataSource={dataItemMaster}
          pagination={false}
          loading={loadingDataItemMaster}
          scroll={{ x: 'max-width', y: 350 }}
          rowKey={(child) => child.key} // Make sure each child row has a unique key
          expandable={{ expandedRowKeys: dataItemMasterKeys, showExpandColumn: false }}
          rowClassName={(row) => (row.key ? 'row-group' : '')}
          rowHoverable={false}
          columns={[
            { key: 'title', dataIndex: 'title', title: 'TITLE', width: 170 },

            { key: 'tr_item__qty', dataIndex: 'tr_item__qty', title: 'PAX', width: 70 },
            {
              key: 'tr_item_bundling__total_net_price',
              dataIndex: 'tr_item_bundling__total_net_price',
              title: 'REVENUE',
              width: 120,
              render: (value) => currencyFormatter({ value }),
            },
          ]}
        />
      </Card>
    </AdminLayout>
  );
}
